SplitFilter

Enum SplitFilter 

#[non_exhaustive]
pub enum SplitFilter<V, S> { WhiteList(V, PhantomData<S>), BlackList(V, PhantomData<S>), None, }

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


WhiteList(V, PhantomData<S>)

Based on SplitBy, show only the tabs that are in the whitelist



BlackList(V, PhantomData<S>)

Based on SplitBy, show only the tabs that are not in the blacklist



None

Show all the tabs

Implementations

Source

impl<V, S> SplitFilter<V, S>
where S: PartialEq<String>, V: AsRef<[S]>,

pub fn whitelist(items: V) -> Self

Based on SplitBy, show only the tabs that are in the whitelist

pub fn blacklist(items: V) -> Self

Based on SplitBy, show only the tabs that are not in the blacklist

Source

impl SplitFilter<Vec<String>, String>

pub fn none() -> Self

Show all the tabs

Source

impl<V, S> SplitFilter<V, S>
where S: PartialEq<String>, V: AsRef<[S]>,

pub fn filter<'a>(&self, target: String) -> Option<String>