#[non_exhaustive]pub enum SplitFilter<V, S> {
WhiteList(V, PhantomData<S>),
BlackList(V, PhantomData<S>),
None,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
WhiteList(V, PhantomData<S>)
Based on SplitBy, show only the tabs that are in the whitelist
BlackList(V, PhantomData<S>)
Based on SplitBy, show only the tabs that are not in the blacklist
None
Show all the tabs
Implementations
Sourceimpl<V, S> SplitFilter<V, S>
impl<V, S> SplitFilter<V, S>